@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import re
 from typing import Union
 from time import sleep
 
@@ -12,6 +11,7 @@ from logzero import logger
 
 from chaosk8s.deployment.actions import scale_deployment
 from chaosk8s.deployment.probes import deployment_available_and_healthy
+from chaosk8ext.deployment import deployment_to_skip
 
 from p2.driver.k8s import k8s
 
@@ -133,9 +133,3 @@ def scale_all_down_up(
         logger.error("Error: not able to scale namespace {}: {}".format(ns, str(e)))
         raise ActivityFailed(
             "Failed to scale namespace '{ns}': {e}".format(ns=ns, e=str(e)))
-
-def deployment_to_skip(skip: list, name: str):
-    for token in skip:
-        if re.search(token, name):
-            return True
-    return False
