@@ -10,6 +10,7 @@ from logzero import logger
 
 from chaosk8s import create_k8s_api_client
 from chaosk8s.pod.probes import read_pod_logs
+from chaosk8ext.deployment import deployment_to_skip
 
 from p2.driver.k8s import k8s
 
@@ -31,6 +32,8 @@ def all_deployments_available_and_healthy(
         api = k8s.Api(context=context)
         deployments = api.deployments_for_namespace(ns)
         for name in deployments:
+            if deployment_to_skip(skip, name):
+                continue
             if deployments[name]["status"]["available_replicas"] != \
                     deployments[name]["status"]["replicas"]:
                 raise ActivityFailed(f"Deployment '{name}' is not healthy")
